In src/menus.C, I made the following changes. However, the "n"
keyboard shortcut off the File->Import submenu is still not activated.

What am I missing?

Index: src/menus.C
===================================================================
RCS file: /usr/local/lyxsrc/cvsroot/lyx-1_0_x/src/menus.C,v
retrieving revision 1.11
diff -u -r1.11 menus.C
--- menus.C     1999/04/26 21:48:36     1.11
+++ menus.C     1999/05/04 18:43:56
@@ -407,10 +407,12 @@
                                     _("Import%t"
                                       "|LaTeX...%x30"
                                       "|Ascii Text as Lines...%x31"
-                                      "|Ascii Text as Paragraphs%x32"));
+                                      "|Ascii Text as Paragraphs%x32"
+                                      "|Noweb%x33"));
        fl_setpup_shortcut(SubFileImport, 30, scex(_("FIM|Ll#l#L")));
        fl_setpup_shortcut(SubFileImport, 31, scex(_("FIM|Aa#a#A")));
        fl_setpup_shortcut(SubFileImport, 32, scex(_("FIM|Pp#p#P")));
+       fl_setpup_shortcut(SubFileImport, 33, scex(_("FIM|Nn#n#N")));
 
        // Export sub-menu
 
@@ -495,8 +497,9 @@
 
        bool hasReLyX = lyxrc->relyx_command != "none";
        if (!hasReLyX) {
                // Disable import LaTeX
                fl_setpup_mode(SubFileImport, 30, FL_PUP_GREY);
+               fl_setpup_mode(SubFileImport, 33, FL_PUP_GREY);
        }
 
        if (!hasLaTeX) {
@@ -566,6 +569,8 @@
                break;
        case 32: tmpfunc->Dispatch(LFUN_IMPORT, "asciiparagraph");
                break;
+       case 33: tmpfunc->Dispatch(LFUN_IMPORT, "noweb");
+               break;
        case 16: // export menu
        case 40:
                if (!LinuxDoc)
@@ -621,15 +626,18 @@
                                     _("Import%t"
                                       "|LaTeX...%x15"
                                       "|Ascii Text as Lines...%x16"
-                                      "|Ascii Text as Paragraphs...%x17"));
+                                      "|Ascii Text as Paragraphs...%x17"
+                                      "|Noweb...%x18"));
        fl_setpup_shortcut(SubFileImport, 15, scex(_("FIM|Ll#l#L")));
        fl_setpup_shortcut(SubFileImport, 16, scex(_("FIM|Aa#a#A")));
        fl_setpup_shortcut(SubFileImport, 17, scex(_("FIM|Pp#p#P")));
+       fl_setpup_shortcut(SubFileImport, 18, scex(_("FIM|Nn#n#N")));
 
        bool hasReLyX = lyxrc->relyx_command != "none";
        if (!hasReLyX) {
                // Disable import LaTeX
                fl_setpup_mode(SubFileImport, 15, FL_PUP_GREY);
+               fl_setpup_mode(SubFileImport, 18, FL_PUP_GREY);
        }
 
        // This can be done cleaner later.
@@ -691,6 +699,8 @@
        case 16: tmpfunc->Dispatch(LFUN_IMPORT, "ascii");
                break;
        case 17: tmpfunc->Dispatch(LFUN_IMPORT, "asciiparagraph");
+               break;
+       case 18: tmpfunc->Dispatch(LFUN_IMPORT, "noweb");
                break;
        case 5:
                tmpfunc->Dispatch(LFUN_QUIT);
@@ -495,8 +497,9 @@
        bool hasReLyX = lyxrc->relyx_command != "none";
        if (!hasReLyX) {
-               // Disable import LaTeX
+               // Disable import LaTeX and Noweb
                fl_setpup_mode(SubFileImport, 30, FL_PUP_GREY);
@@ -621,15 +626,18 @@
        bool hasReLyX = lyxrc->relyx_command != "none";
        if (!hasReLyX) {
-               // Disable import LaTeX
+               // Disable import LaTeX and Noweb
                fl_setpup_mode(SubFileImport, 15, FL_PUP_GREY);

Reply via email to